==> velobox_update_3.0.4.tar.gz: usr/local/vmkstationd3.1.0_U/htdocs/production/js/dashboard.js <==
/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

//DEV{}
function dev(params) {
  document.getElementsByClassName("version")[0].innerHTML="3.0.3_2"
}

/* 
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/
// SATTELDRUCK
const host_s = `http://${location.host}`;
const ws_s = `ws://${location.host}`;
const apps_s = "satteldruckanalyse";

//HOCKER
const hocker = document.getElementById('hip').value || null;
localStorage.setItem('smartcube',hocker)
const host_h = `http://${hocker}`;
const ws_h = `ws://${hocker}/messages`;
const apps_h = null;

let con_img = document.getElementById("img_Seatbonemeasurement");
let link_sitzknochen = document.getElementById("Seatbonemeasurement");
var wsH = {};
let side_smartcube = document.getElementById('sitzknochen-menu');

let inter_Seatbonemeasurement = setInterval( () => {
  if(hocker!=null){
    wsH = new WebSocket(ws_h, ["soap", "wamp"]);
  
    wsH.onopen = (event) =>{
      localStorage.setItem('smartcube_link',true)
      document.getElementById('Seatbonemeasurement').classList.remove('no-hocker')
      document.getElementById('img_Seatbonemeasurement').classList.remove('uk-blend-luminosity')
    }
  }
  clearInterval(inter_Seatbonemeasurement);
}, 1000);








function noHocker() {
  //console.log(link_sitzknochen,con_img,side_smartcube);
  //link_sitzknochen.classList.add("no-hocker");
  //con_img.classList.add('uk-blend-luminosity');
  //link_sitzknochen.setAttribute("onclick", 'LinkTo("system.tcls#smartcube")');
  //side_smartcube.setAttribute('href','/production/system.tcls');
  //localStorage.setItem('hocker',"off");
}

localStorage.removeItem('product1');
localStorage.removeItem('product2');
localStorage.removeItem('session_note');
localStorage.removeItem('session');
localStorage.removeItem('client_info');
localStorage.removeItem('client_id');
localStorage.removeItem('client_mail');
localStorage.removeItem('client_name');
localStorage.removeItem('note_session');

==> velobox_update_3.0.5.tar.gz: usr/local/vmkstationd3.1.0_U/htdocs/production/js/dashboard.js <==
/*
Copyright (C) 2021 Velometrik GmbH
<http://www.velometrik.de/>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/


/* 
    Created on : 04.06.2021, 21:08:29
    Author     : Peter Bauer
*/
// SATTELDRUCK
//const host_s = `http://${location.host}`;
//const ws_s = host_s.replace('http','ws');
//const apps_s = "satteldruckanalyse";

//HOCKER
const hocker = document.getElementById('hip').value || null;
localStorage.setItem('smartcube',hocker)
const host_h = `http://${hocker}`;
const ws_h = `ws://${hocker}/messages`;
const apps_h = null;

let con_img = document.getElementById("img_Seatbonemeasurement");
let link_sitzknochen = document.getElementById("Seatbonemeasurement");
var wsH = {};
let side_smartcube = document.getElementById('sitzknochen-menu');

/* The code block is creating a setInterval function that runs every 1000 milliseconds (1 second).
Inside the function, it checks if the variable `hocker` is not null. If `hocker` is not null, it
creates a new WebSocket connection using the `ws_h` URL and the protocols "soap" and "wamp". */
let inter_Seatbonemeasurement = setInterval( () => {
  if(hocker!=null){
    wsH = new WebSocket(ws_h, ["soap", "wamp"]);
  
    wsH.onopen = (event) =>{
      localStorage.setItem('smartcube_link',true)
      document.getElementById('Seatbonemeasurement').classList.remove('no-hocker')
      document.getElementById('img_Seatbonemeasurement').classList.remove('uk-blend-luminosity')
    }
  }
  clearInterval(inter_Seatbonemeasurement);
}, 1000);


browser()

function browser(){
  let ele = document.getElementById('browser')
  let os_browser = navigator.userAgent

  if(os_browser.includes('Win64') && os_browser.includes('Firefox')){
    ele.removeAttribute('class')
  }
  
}



function noHocker() {
  //console.log(link_sitzknochen,con_img,side_smartcube);
  //link_sitzknochen.classList.add("no-hocker");
  //con_img.classList.add('uk-blend-luminosity');
  //link_sitzknochen.setAttribute("onclick", 'LinkTo("system.tcls#smartcube")');
  //side_smartcube.setAttribute('href','/production/system.tcls');
  //localStorage.setItem('hocker',"off");
}

localStorage.removeItem('product1');
localStorage.removeItem('product2');
localStorage.removeItem('session_note');
localStorage.removeItem('session');
localStorage.removeItem('client_info');
localStorage.removeItem('client_id');
localStorage.removeItem('client_mail');
localStorage.removeItem('client_name');
localStorage.removeItem('note_session');
